@@ -1,5 +1,5 @@
 /*
- * SirvNET Services is copyright (c) 1998-2001 Trevor Klingbeil.
+ * SirvNET Services is copyright (c) 1998-2002 Trevor Klingbeil.
  *     E-mail: <priority1@dal.net>
  * Originally based on EsperNet Services(c) by Andy Church.
  * This program is free but copyrighted software; see the file COPYING for
@@ -112,6 +112,10 @@ void do_sjoin(char *source, int ac, char **av)
                 chan->mode |= CMODE_M;
                 break;
 
+           case 'M':
+                chan->mode |= CMODE_m;
+                break;
+
             case 'R':
                 chan->mode |= CMODE_r;
                 break;
@@ -136,6 +140,11 @@ void do_sjoin(char *source, int ac, char **av)
                 chan->mode |= CMODE_C;
                 break;
 
+            case 'O':
+                chan->mode |= CMODE_o;
+                break;
+
+
             case 'l':
                 if (chan->limit > 0)
                    chan->limit = 0;
@@ -711,6 +720,21 @@ void do_cmode(const char *source, int ac, char **av)
 		chan->mode &= ~CMODE_M;
 	    break;
 
+	case 'O':
+	    if (add)
+		chan->mode |= CMODE_o;
+	    else
+		chan->mode &= ~CMODE_o;
+	    break;
+
+	case 'M':
+	    if (add)
+		chan->mode |= CMODE_m;
+	    else
+		chan->mode &= ~CMODE_m;
+	    break;
+
+
         case 'R':
 	    if (add)
                 chan->mode |= CMODE_r;
