@@ -1,6 +1,6 @@
 
 /*
- * SirvNET Services is copyright (c) 1998-2001 Trevor Klingbeil.
+ * SirvNET Services is copyright (c) 1998-2002 Trevor Klingbeil.
  *     E-mail: <priority1@dal.net>
  * This program is free but copyrighted software; see the file COPYING for
  * details.
@@ -122,6 +122,10 @@ short REMINDER = 3;
 short NOHOST_CONF = 0;
 short AUTO_NOHOST = 0;
 
+short getpass_enable = 1;
+short listchans_enable = 1;
+short enforce_default = 0;
+
 char *services_roots[MAX_SERVROOTS];
 char *services_admins[MAX_SERVADMINS];
 char *services_opers[MAX_SERVOPERS];
@@ -551,6 +555,20 @@ log("DEF: %s", DEF_AKICK_REASON);
          MOTD_UPDATE = atoi(pargv[1]);
          return 0;
 
+     } else if (!stricmp(buf, "GETPASS")) {
+         getpass_enable = atoi(pargv[1]);
+         return 0;
+
+     } else if (!stricmp(buf, "LISTCHANS")) {
+         listchans_enable = atoi(pargv[1]);
+         return 0;
+
+     } else if (!stricmp(buf, "ENFORCE")) {
+         enforce_default = atoi(pargv[1]);
+         return 0;
+
+
+
      } else if (!stricmp(buf, "MLOCK")) {
          char tmp[128];
          int add = 1;
