@@ -1,6 +1,6 @@
 /* MemoServ functions.
  *
- * SirvNET Services is copyright (c) 1998-2001 Trevor Klingbeil.
+ * SirvNET Services is copyright (c) 1998-2002 Trevor Klingbeil.
  *     E-mail: <priority1@dal.net>
  * Originally based on EsperNet Services(c) by Andy Church.
  * This program is free but copyrighted software; see the file COPYING for
@@ -257,6 +257,7 @@ void load_ms_dbase(void)
       case 5:
       case 6:
       case 7:
+      case 8:
 	for (i = 33; i < 256; ++i) {
 	    while (fgetc(f) == 1) {
 		ml = smalloc(sizeof(MemoList));
@@ -500,8 +501,10 @@ static void staff_send(const char *nick, const char *text, const char *sender)
 
    if (ni->forward) {
        nif = findnick(ni->forward);
-       if (nif && nif->flags & NI_NOMEMO)
+       if (nif && nif->flags & NI_NOMEMO) {
+              free(name);
               return;
+       }
        free(name);
        name = sstrdup(ni->forward);
    }
@@ -1326,6 +1329,8 @@ static void do_forward(const char *source)
             notice(s_MemoServ,source, MS_NOFORWARD);
             slog("MS -F (%s!%s@%s) [%s -> %s]",
                  source, u->username, u->host, ni->nick, ni->forward);
+            if (ni->forward)
+                free(ni->forward);
             ni->forward = NULL;
         } else
             notice(s_MemoServ, source, "You do not currently have memo's forwarding");
@@ -1351,6 +1356,8 @@ static void do_forward(const char *source)
             notice(s_MemoServ,source,"Your memos are now forwarding to %s",
         	    nick);
 
+        if (ni->forward)
+           free(ni->forward);
 	ni->forward = sstrdup(nick);
         show_next_db(source, s_MemoServ);
         slog("MS F (%s!%s@%s) [%s -> %s]",
@@ -2150,6 +2157,7 @@ void sendpass_ns(const char *source, NickInfo *ni) {
     char text[512];
     FILE *fs = fopen(SERVICES_SIG, "r");
     FILE *f = fopen("memo.txt", "a");
+    User *u = finduser(source);
 
       tm = *localtime(&now);
       strftime(timebuf, sizeof(timebuf), "%a %b %d %H:%M:%S %Y %Z", &tm);
@@ -2163,8 +2171,8 @@ void sendpass_ns(const char *source, NickInfo *ni) {
                fprintf(f, "From: %s <%s>\n", NETWORK_NAME, RETURN_EMAIL);
                fprintf(f, "To: %s <%s>\n", ni->nick, ni->regemail);
                fprintf(f, "Subject: %s Password Retreival\n\n", NETWORK_NAME);
-               fprintf(f, "Password Retreival (by: %s) received on %s for %s:\n %s \n",
-                      source, timebuf, ni->nick, text);
+               fprintf(f, "Password Retreival [by: %s (%s@%s)] received on %s for %s:\n %s \n",
+                      source, u->username, u->host, timebuf, ni->nick, text);
                fclose(f);
                if (fs) {
                   sprintf(cmdbuf, "cat %s >> memo.txt", SERVICES_SIG);
@@ -2231,8 +2239,8 @@ void sendpass_cs(const char *source, ChannelInfo *ci) {
                fprintf(f, "To: %s <%s>\n", ni->nick, ni->regemail);
                fprintf(f, "Subject: %s Password Retrieval\n\n",
                       NETWORK_NAME);
-               fprintf(f, "Channel Password Retreival (by %s) received on %s for %s:\n %s \n",
-                     source, timebuf, ci->name, text);
+               fprintf(f, "Channel Password Retreival [by %s (%s@%s)] received on %s for %s:\n %s \n",
+                     source, u->username, u->host, timebuf, ci->name, text);
                fclose(f);
                if (fs) {
                   sprintf(cmdbuf, "cat %s >> memo.txt", SERVICES_SIG);
