@@ -1,5 +1,5 @@
 /*
- * SirvNET Services is copyright (c) 1998-2001 Trevor Klingbeil.
+ * SirvNET Services is copyright (c) 1998-2002 Trevor Klingbeil.
  *     E-mail: <priority1@dal.net>
  * This program is free but copyrighted software; see the file COPYING for
  * details.
@@ -955,6 +955,11 @@ static void do_sa(const char *source)
                         nick);
                     return;
                 }
+                if (is_services_root(nick)) {
+                    notice(s_RootServ, source, "Error - %s is a higher access than Services Administrator", nick);
+                    return;
+                }
+
                 if (!services_admins[i])
                     break;
             }
@@ -976,11 +981,6 @@ static void do_sa(const char *source)
                         services_opers[i] = NULL;
                 }
 
-                for (i = 0; i < MAX_SERVROOTS; i++) {
-                    if (services_roots[i] && !stricmp(nick, services_roots[i]))
-                        services_roots[i] = NULL;
-                }
-
 
 	    } else {
                 notice(s_RootServ, source,
